/*-------------------------------------------------------------------------
 * Copyright (C) 2000 Caldera Systems, Inc
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 *    Neither the name of Caldera Systems nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * `AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE CALDERA
 * SYSTEMS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;  LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *-------------------------------------------------------------------------*/

/** Implementation of general debugging code.
 *
 * @file       slp_debug.c
 * @author     John Calcote (jcalcote@novell.com)
 * @attention  Please submit patches to http://www.openslp.org
 * @ingroup    CommonCodeDebugAssert
 */

#include "slp_types.h"
#include "slp_debug.h"

/** Displays a message when SLP_ASSERT macro expression fails
 * 
 * Only called by the SLP_ASSERT macro, and then only if the assertion
 * fails.
 * 
 * @param[in] assertion - A text string indicating the failed expression.
 * @param[in] file - The file name in which the assertion failed.
 * @param[in] line - The line number on which the assertion failed.
 * 
 * @return Zero.
 */
int SLPAssertionFailed(const char * assertion, const char * file, int line)
{
#ifdef _WIN32
   char errmsg[2048];
   _snprintf(errmsg, sizeof(errmsg),
         "Debug assertion \"%s\" failed.\n\tLine %d of file %s.\n", 
         assertion, line, file);
   FatalAppExit(0, errmsg);
#else
   fprintf(stderr, "Debug assertion \"%s\" failed."
         "\n\tLine %d of file %s.\n", assertion, line, file);
   /* exit(-1); */
#endif
   return 0;
}

/*=========================================================================*/
